@@ -202,6 +202,20 @@ class DbtClient:
             raise ValueError("timeout_action must be 'raise', 'return' or a callable")
 
         response_data = self._request(method, params=params)
+
+        while "error" in response_data and response_data['error']['code'] == 10010:
+            if (timeout is not None) and (time() >= max_time):
+                if callable(timeout_action):
+                    timeout_action()
+                elif timeout_action == "raise":
+                    raise Exception("Timed out waiting for response")
+                elif timeout_action == "return":
+                    return response_data
+
+            sleep(DEFAULT_SYNC_SLEEP)
+
+            response_data = self._request(method, params=params)
+
         if "result" in response_data:
             if "request_token" in response_data["result"]:
                 request_token = response_data["result"]["request_token"]
